@@ -17,7 +17,8 @@ dolloar_regex_compile = re.compile(r"\$\$")
 # variable notation, e.g. ${var} or $var
 variable_regex_compile = re.compile(r"\$\{(\w+)\}|\$(\w+)")
 # function notation, e.g. ${func1($var_1, $var_3)}
-function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\.\-/\s=,]*)\)\}")
+# function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\.\-/\s=,]*)\)\}")
+function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\.\-/\s=,\"\']*)\)\}")
 
 
 def parse_string_value(str_value: Text) -> Any:
@@ -196,10 +197,14 @@ def parse_function_params(params: Text) -> Dict:
     if params_str == "":
         return function_meta
 
+    #TODO fengqi修改未完善
+
     args_list = params_str.split(",")
     for arg in args_list:
         arg = arg.strip()
-        if "=" in arg:
+        if "select" in arg or "update" in arg:
+            function_meta["args"].append(parse_string_value(arg))
+        elif "=" in arg:
             key, value = arg.split("=")
             function_meta["kwargs"][key.strip()] = parse_string_value(value.strip())
         else:
