@@ -142,6 +142,7 @@ class mkrunner(object):
         prepare_upload_step(step, self.__project_meta.functions)
         request_dict = step.request.dict()
         request_dict.pop("upload", None)
+
         parsed_request_dict = parse_data(
             request_dict, step.variables, self.__project_meta.functions
         )
@@ -151,6 +152,27 @@ class mkrunner(object):
         )
         step.variables["request"] = parsed_request_dict
 
+        body = "params"
+        if not parsed_request_dict["params"]:
+            body = "data"
+
+
+        code_function = "data_sign"
+        if "function" in parsed_request_dict[body]:
+            code_function = parsed_request_dict[body]["function"]
+            del parsed_request_dict[body]["function"]
+
+        if "api_sign" not in parsed_request_dict[body] and "code_secret" in parsed_request_dict[body]:
+
+            import json
+
+            app_secret = parsed_request_dict[body]["code_secret"]
+
+            del parsed_request_dict[body]["code_secret"]
+
+            api_sign = self.__project_meta.functions[code_function](json.dumps(parsed_request_dict[body]), app_secret)
+            parsed_request_dict[body]["api_sign"] = api_sign
+
         # setup hooks
         if step.setup_hooks:
             self.__call_hooks(step.setup_hooks, step.variables, "setup request")
